@@ -235,12 +235,14 @@ def assignLongReadToSNPs(samPath,bedPath,referencePath,minQ,minMQ,minAln,outputP
 
     for line in samLines: #For each sam record
         #Initializing a lot of things
+        sequence=line[9]
+        if sequence=="*": #Only seen this happen when the MAPQ is 0 for a secondary alignment
+            continue
         readName=line[0]
         ctgName=line[2]
         refPosition=int(line[3]) #SamFiles are already in 1-base
         MQ=int(line[4])
         cigar=line[5]
-        sequence=line[9]
         QLine=line[10]
         readPosition=0 #The base of readPosition is irrelevant, it starts at 0 because python lists are 0-based (sequence[0])
         lineBases=[]
@@ -427,7 +429,7 @@ def getAvgFastQScore(fastQScoreStr):
     return avgScore
 
 def generateLongReadFastQFiles(haplotigReadNameFilePath,longReadFastQFilePath,outputPath):
-    clusterStatsText=""
+    ##clusterStatsText=""
     haplotigReadDict={}
     haplotigReadNameFile=open(haplotigReadNameFilePath,"r")
     for line in haplotigReadNameFile:
@@ -444,7 +446,7 @@ def generateLongReadFastQFiles(haplotigReadNameFilePath,longReadFastQFilePath,ou
     haplotigReadNameFile.close()
 
     longReadData={}
-    longReadMetaData={}
+    ##longReadMetaData={}
 
     try:
         longReadFastQFile=gzip.open(longReadFastQFilePath,"rt")
@@ -463,27 +465,31 @@ def generateLongReadFastQFiles(haplotigReadNameFilePath,longReadFastQFilePath,ou
             longReadData[readName]=[]
         else:
             if i%4==3:
-                longReadMetaData[readName]=getAvgFastQScore(line)
+                pass
+                ##longReadMetaData[readName]=getAvgFastQScore(line)
             longReadData[readName].append(line)
         i+=1
     longReadFastQFile.close()
 
     for haplotigName, reads in haplotigReadDict.items():
         haplotigFastQText=""
-        totalScore=0
+        ##totalScore=0
         for read in reads:
             read="@"+read
-            totalScore+=longReadMetaData[read]
-            readText=read+"\n"+"\n".join(longReadData[read])+"\n"
-            haplotigFastQText+=readText
-        clusterStatsText+=haplotigName+"\t"+str(len(set(reads)))+"\t"+str(round(totalScore/len(reads)))+"\n"
+            ##totalScore+=longReadMetaData[read]
+            try:
+                readText=read+"\n"+"\n".join(longReadData[read])+"\n"
+                haplotigFastQText+=readText
+            except:
+                pass
+        ##clusterStatsText+=haplotigName+"\t"+str(len(set(reads)))+"\t"+str(round(totalScore/len(reads)))+"\n"
         haplotigFile=gzip.open(outputPath+haplotigName+".fastq.gz",'wt')
         haplotigFile.write(haplotigFastQText)
         haplotigFile.close()
 
-    clusterStatsFile=open(outputPath+"clusterStats.tsv", 'w')
-    clusterStatsFile.write(clusterStatsText)
-    clusterStatsFile.close()
+    ##clusterStatsFile=open(outputPath+"clusterStats.tsv", 'w')
+    ##clusterStatsFile.write(clusterStatsText)
+    ##clusterStatsFile.close()
 
     return "Successfully generated phased FastQ files"
 
